.. _tutorials:

Tutorials
=========

This page contains a few tutorials for using Matplotlib.  For the old tutorials, see :ref:`below <user_guide_tutorials>`.

For shorter examples, see our :ref:`examples page <examples-index>`.
You can also find :ref:`external resources <resources-index>` and
a :ref:`FAQ <howto-faq>` in our :ref:`user guide <users-guide-index>`.

.. minigallery::
   ../galleries/tutorials/pyplot.py
   ../galleries/tutorials/coding_shortcuts.py
   ../galleries/tutorials/images.py
   ../galleries/tutorials/lifecycle.py
   ../galleries/tutorials/artists.py

.. toctree::
   :hidden:

   /tutorials/pyplot
   /tutorials/coding_shortcuts
   /tutorials/images
   /tutorials/lifecycle
   /tutorials/artists

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: tutorials_python.zip </tutorials/tutorials_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: tutorials_jupyter.zip </tutorials/tutorials_jupyter.zip>`


.. _user_guide_tutorials:

User guide tutorials
--------------------

Many of our tutorials were moved from this section to :ref:`users-guide-index`:

Introductory
^^^^^^^^^^^^

- :ref:`quick_start`
- :ref:`customizing`
- :ref:`animations`

Intermediate
^^^^^^^^^^^^

- :ref:`legend_guide`
- :ref:`color_cycle`
- :ref:`constrainedlayout_guide`
- :ref:`tight_layout_guide`
- :ref:`arranging_axes`
- :ref:`autoscale`
- :ref:`imshow_extent`

Advanced
^^^^^^^^

- :ref:`blitting`
- :ref:`paths`
- :ref:`patheffects_guide`
- :ref:`transforms_tutorial`

Colors
^^^^^^

See :ref:`tutorials-colors`.

Text
^^^^

See :ref:`tutorials-text`.

Toolkits
^^^^^^^^

See :ref:`tutorials-toolkits`.
